@@ -2,7 +2,21 @@
    Example showing how to use different decks and evaluation rule sets.
 
    Michael Maurer, Apr 2002
-*/
+
+ *  This package is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 dated June, 1991.
+ *
+ *  This package is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this package; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
+ *  MA 02110-1301, USA.
+ */
 
 #include <stdio.h>
 #include <string.h>
@@ -178,8 +192,8 @@ testOmaha8(const char *holestr, const char *boardstr) {
   int nboard;
   int c;
   int ret;
-  HandVal hival;
-  LowHandVal loval;
+  HandVal hival = 0;
+  LowHandVal loval = 0;
   char str[80], hstr[80], bstr[80];
   char *p;
 
