@@ -2,7 +2,21 @@
 /*
   See comments in enumord.h.
   Michael Maurer, Jun 2002
-*/
+
+ *  This package is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 dated June, 1991.
+ *
+ *  This package is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this package; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
+ *  MA 02110-1301, USA.
+ */
 
 #include <stdlib.h>
 #include "enumord.h"
@@ -27,7 +41,7 @@ enum_rankelem_compare(const void *p1, const void *p2) {
 }
 
 void
-enum_ordering_rank(int *hands, int noqual, int nplayers, int *ranks,
+enum_ordering_rank(HandVal *hands, int noqual, int nplayers, int *ranks,
                    int reverse)
 {
   enum_rankelem_t elems[ENUM_ORDERING_MAXPLAYERS];
